[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0) 

<span>![<span>Logo</span>](assets/Logo.png)</span> 

DED SLICER (ded ˈslaɪ.sər) or dee three dee slick three arrr is a utility for discombobulating geometry into paths for direct energy deposition that might work. Garantees are as firm as the current documentation. Start it up, click the buttons, read the tool tips and see what it does.

# Installation
Install it from source using the tarball in the dist folder, or try your luck with PyPI:

~~~
pip install d3dslic3r
~~~

# Getting it to run

It was written with Python 3.11, no garantees that it will run with anything more, it may run on 3.9, but don't test your luck.
~~~
python -m d3dslic3r.main
~~~